"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const vue = require("vue");
function select(sel) {
  return (store) => vue.computed(() => sel(store.value));
}
const contextKey_original = Symbol("redux-original-store");
const contextKey_adapted = Symbol("redux-adapted-store");
function useSelector(sel) {
  return select(sel)(useStore());
}
function useStore() {
  return vue.inject(contextKey_adapted);
}
function useDispatch() {
  return useStore().dispatch;
}
function createPlugin(reduxStore) {
  const plugin = {
    install: (app) => {
      const vueReduxStore = fromRedux(reduxStore);
      app.provide(contextKey_adapted, vueReduxStore);
      app.provide(contextKey_original, reduxStore);
    }
  };
  return plugin;
}
function fromRedux(reduxStore) {
  const vueReduxStore = vue.shallowRef(reduxStore.getState());
  vueReduxStore.dispatch = reduxStore.dispatch;
  reduxStore.subscribe(() => {
    vueReduxStore.value = reduxStore.getState();
  });
  return vue.readonly(vueReduxStore);
}
exports.contextKey_adapted = contextKey_adapted;
exports.contextKey_original = contextKey_original;
exports.createPlugin = createPlugin;
exports.fromRedux = fromRedux;
exports.useDispatch = useDispatch;
exports.useSelector = useSelector;
exports.useStore = useStore;
//# sourceMappingURL=vue-redux-adapter.js.map
