import { computed, inject, shallowRef, readonly } from "vue";
function select(sel) {
  return (store) => computed(() => sel(store.value));
}
const contextKey_original = Symbol("redux-original-store");
const contextKey_adapted = Symbol("redux-adapted-store");
function useSelector(sel) {
  return select(sel)(useStore());
}
function useStore() {
  return inject(contextKey_adapted);
}
function useDispatch() {
  return useStore().dispatch;
}
function createPlugin(reduxStore) {
  const plugin = {
    install: (app) => {
      const vueReduxStore = fromRedux(reduxStore);
      app.provide(contextKey_adapted, vueReduxStore);
      app.provide(contextKey_original, reduxStore);
    }
  };
  return plugin;
}
function fromRedux(reduxStore) {
  const vueReduxStore = shallowRef(reduxStore.getState());
  vueReduxStore.dispatch = reduxStore.dispatch;
  reduxStore.subscribe(() => {
    vueReduxStore.value = reduxStore.getState();
  });
  return readonly(vueReduxStore);
}
export {
  contextKey_adapted,
  contextKey_original,
  createPlugin,
  fromRedux,
  useDispatch,
  useSelector,
  useStore
};
//# sourceMappingURL=vue-redux-adapter.mjs.map
